@@ -50,20 +50,21 @@ class AppManager(object):
     def initialise_apps(cls, apps_dir):
         if DynamicSchemaName.use_app_schemas:
             cls._create_schema_if_required(create_engine(App.overridden_global_sqla_engine), DynamicSchemaName.COMPUTE_NODE_SCHEMA_NAME)
-        
-        dirs = [dir_ for dir_ in apps_dir.split(";") if os.path.isdir(dir_)]
-        for dir_ in dirs:
-            path, module_name = os.path.split(dir_)
-            DynamicSchemaName.set_schema_name(module_name)
-            sys.path.append(path)
 
-            module = importlib.import_module(module_name)  # Importing the module here gives it the chance to set a custom value for DynamicSchemaName.schema_name
+        for dir_line in apps_dir.split("\n"):
+            dirs = [dir_ for dir_ in dir_line.split(";") if os.path.isdir(dir_)]
+            for dir_ in dirs:
+                path, module_name = os.path.split(dir_)
+                DynamicSchemaName.set_schema_name(module_name)
+                sys.path.append(path)
 
-            AppManager._create_app_if_possible(
-                possible_app_package=module,
-                possible_app_schema_name=DynamicSchemaName.schema_name,
-                possible_app_package_file_path=dir_,
-            )
+                module = importlib.import_module(module_name)  # Importing the module here gives it the chance to set a custom value for DynamicSchemaName.schema_name
+
+                AppManager._create_app_if_possible(
+                    possible_app_package=module,
+                    possible_app_schema_name=DynamicSchemaName.schema_name,
+                    possible_app_package_file_path=dir_,
+                )
 
     @classmethod
     def _create_app_if_possible(cls, possible_app_package, possible_app_schema_name, possible_app_package_file_path):
@@ -123,6 +124,7 @@ class AppManager(object):
     def _create_schema_if_required(cls, engine, schema_name):
         """Schema creation is required if using app schemas, and the schema does not exist yet."""
         if schema_name and not cls._schema_exist(engine, schema_name):
+            print("Creating schema %s..." % schema_name)
             engine.connect().execute(CreateSchema(schema_name))
 
     @classmethod
