@@ -30,7 +30,7 @@ class App(object):
     global_app_indexer = 0
     overridden_global_sqla_engine = ''
 
-    def __init__(self, config):
+    def __init__(self, config=None):
         self.id = App.global_app_indexer
         App.global_app_indexer += 1
         self.config = config
@@ -223,7 +223,7 @@ class AppWithDataSets(App):
 
     """
 
-    def __init__(self, config):
+    def __init__(self, config=None):
         App.__init__(self, config)
 
     def _init_step_groups(self):
