@@ -118,7 +118,10 @@ class AppDataSet(ORMBase):
                 meta=current_task._running_task_meta
             )
         except:  # Not using Celery current_task doesn't exist.
-            self._running_task.add_messages(new_messages)
+            try:
+                self._running_task.add_messages(new_messages)
+            except AttributeError:  # no attr self._running_task
+                print("Error sending progress messages: {}. Called outside ExecuteFunction widget?.".format([m.text for m in new_messages]))
 
     def current_celery_task_terminated(self):
         return self.query(CeleryTask.terminated_by_user).filter_by(task_id=current_task.request.id).scalar()
