@@ -213,23 +213,30 @@ class ExcelWriter(object):
             col_names = mapping.required_column_names
             if col_names:
                 for col in col_names:
-                    worksheet.cell(row=0, column=col_names.index(col)).value = col
+                    worksheet.cell(row=1, column=col_names.index(col)+1).value = col # new version of openpyxl does not like zero based cols and rows!
 
                 for i, obj in enumerate(mapping.objects):
                     for j, col_name in enumerate(col_names):
+                        excel_col = j + 1
                         try:
                             value = getattr(obj, mapping.get_attribute_from_column_name(col_name))
                         except AttributeError:
                             print('Object in ClassWsMappingForExport.objects does not match ClassWsMappingForExport object and col definition')
                             raise
-                        row_num = i + 1  # Add one to row to skip col names header row.
+
+                        if isinstance(value, datetime.timedelta):
+                            value = str(value)
+                        if isinstance(value, datetime.datetime):
+                            value = value.strftime("%H:%M %d/%m/%Y")  # otherwise we wont be able to read it back in
+
+                        row_num = i + 2  # Add one to row to skip col names header row and new version of openpyxl does not like zero based rows.
                         if isinstance(value, basestring):  # Have to force string. Otherwise will automatically coerce to things. Eg scientific notation: '110E04' will save as 1100000.0
-                            worksheet.cell(row=row_num, column=j).set_value_explicit(
+                            worksheet.cell(row=row_num, column=excel_col).set_explicit_value(
                                 value=value,
                                 data_type=openpyxl.cell.Cell.TYPE_STRING
                             )
                         else:
-                            worksheet.cell(row=row_num, column=j).value = value  # Add one to row to skip col names header row.
+                            worksheet.cell(row=row_num, column=excel_col).value = value  # Add one to row to skip col names header row.
         return wb
 
 
@@ -408,8 +415,8 @@ class ExcelReader(object):
             return cell.value == 1
         return cell.value
 
+
 # ws helper function
 def _ws_headers_as_set(ws):
     headers = ws.row_values(0)
     return set([col.encode('ascii', 'ignore') for col in headers if col is not None])
-
