@@ -71,7 +71,7 @@ def run_app(request):
 def redirect_to_run_app(request):
     if request.only_app:
         return exc.HTTPFound(
-            location=request.route_url('run_app', app_url_name=request.only_app.url_name)  # Must specify port if specify scheme - otherwise breaks
+            location=request.route_url('run_app', app_url_name=request.only_app.url_name, _scheme=request.scheme, _port=request.host_port)  # Must specify port if specify scheme - otherwise breaks
         )
     else:
         raise exc.HTTPNotFound()
@@ -101,16 +101,13 @@ def refresh_widget_from_db(request):
         response = Response(widget_parameters['get_data'])
         response.content_type = 'text/plain'  # Must explicitly set for ie
         return response
-    elif request.widget.get_type() in ["FormWidget", "GridWidget", "SimpleGrid", "ExecuteFunctionWidget"]:  # Don't need to send up
-        return widget_parameters
-    else:
+    elif request.widget.get_type() in ["ChartWidget"]:  # Send to GUI server for processing.
         data = {'widget_type': request.widget.get_type(), 'widget_parameters': widget_parameters}
         response = proxy_request(data)
         response = json.loads(response.text) # Todo: Change to response.content ? 
-
-        if request.widget.get_type() == "KMLMapWidget":  # On client, Openlayers expects the KML. No chance to decode from json.
-            return Response(response['kml'])
         return response
+    else:
+        return widget_parameters
 
 
 @view_config(route_name='export_data_set', permission='run_app')
@@ -125,12 +122,13 @@ def export_data_set(request):
 ### Data Set Management ###
 @view_config(route_name='create_new_data_set', xhr=True, renderer='json', permission='run_app')
 def create_new_data_set(request):
-    if request.app is not None:
-        data_set = request.app.create_new_data_set_for_user(
+    app = request.app
+    if app is not None:
+        data_set = app.create_new_data_set_for_user(
             authenticated_userid(request),
-            request.POST['data_set_template'],
-            request.POST['data_set_name']
+            request.POST['data_set_name'],
         )
+        app.populate_data_set_from_template(data_set, request.POST['data_set_template'])
         return {
             'success': True,
             'dataSetId': data_set.id
@@ -191,7 +189,7 @@ def logout(request):
 @forbidden_view_config(renderer='string')
 def forbidden(request):
     return exc.HTTPFound(
-        location=request.route_url('logout', app_url_name=request.matchdict.get('app_url_name'))
+        location=request.route_url('logout', app_url_name=request.matchdict.get('app_url_name'), _scheme=request.scheme, _port=request.host_port)
     )
 
 
