@@ -67,12 +67,23 @@ class Form(Widget):
 
             self.name = name
             self.input_type = input_type  # Must be defined by options. Options validator uses this.
-            self.options = options  # Must be defined before default_value. Default validator uses this.
+            if self.is_select_element:
+                if compute_options_from is not None:
+                    # self.options = [] # Must be defined before default_value. Default validator uses this.
+                    self._options = []
+                    self.compute_options_from = compute_options_from
+                else:
+                    self.options = options
+                    self.compute_options_from = None
+            else:
+                self.options = options
+                self.compute_options_from = None
+
             self.default_value = default
             self.hidden = hidden
             self.disabled = disabled
             self.label = label if label is not None else self.name
-            self.compute_options_from = compute_options_from if self.options == [] and self.is_select_element else None
+            # self.compute_options_from = compute_options_from if self.options == [] and self.is_select_element else None
 
         def serialise(self):
             return {
@@ -141,15 +152,22 @@ class Form(Widget):
 
                 elif self.input_type in [Form.Element.DATE, Form.Element.TIME, Form.Element.DATETIME]:
                     value = ""
-                elif self.is_select_element:
+                elif self.is_select_element and len(self.options) > 0:
                     value = self.options[0].value  # Checked earlier that if SELECT element, at least one option.
+                elif self.compute_options_from is not None:
+                    value = ""
                 else:
                     raise Form.FormElementException("Default value not provided, and no 'default default' for form element type %s" % self.input_type)
 
             if self.is_select_element:
                 option_values = [o.value for o in self.options]
-                if value not in option_values:
+                if value not in option_values and self.compute_options_from is not None:
+                    if len(option_values) > 0:
+                        self._default_value = option_values[0]
+                elif value not in option_values:
                     raise Form.FormElementException("Default for `select` element exception. Default value '%s' not found in options values: %s" % (value, str(option_values)))
+                else:
+                    pass
 
             self._default_value = value
         ######## END INPUT VALIDATORS #########################
