@@ -68,7 +68,7 @@ class IntersectionKMLMap(KMLMap):
         def LongLat(l):
             return (l.longitude, l.latitude)
 
-        mylocstyle = Style(iconstyle=IconStyle(scale=0.1, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        mylocstyle = Style(iconstyle=IconStyle(scale=0.1, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         LocsFolder = kml.newfolder(name="Intersections")
         for p in [LocsFolder.newpoint(name=str(loc.name), coords=[LongLat(loc)]) for loc in data_set.query(Intersection).all()]:
             p.style = mylocstyle
@@ -83,7 +83,7 @@ class RoadKMLMap(KMLMap):
         def LongLat(l):
             return (l.longitude, l.latitude)
 
-        mylocstyle = Style(iconstyle=IconStyle(scale=0.1, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        mylocstyle = Style(iconstyle=IconStyle(scale=0.1, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         LocsFolder = kml.newfolder(name="Locations")
         for p in [LocsFolder.newpoint(name=str(loc.name), coords=[LongLat(loc)]) for loc in data_set.query(Intersection).all()]:
             p.style = mylocstyle
@@ -103,7 +103,7 @@ class SpanningTreeKMLMap(KMLMap):
         def LongLat(l):
             return (l.longitude, l.latitude)
 
-        mylocstyle = Style(iconstyle=IconStyle(scale=0.1, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        mylocstyle = Style(iconstyle=IconStyle(scale=0.1, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         LocsFolder = kml.newfolder(name="Locations")
         for p in [LocsFolder.newpoint(name=str(loc.name), coords=[LongLat(loc)]) for loc in data_set.query(Intersection).all()]:
             p.style = mylocstyle
