@@ -52,7 +52,7 @@ class TravellingSalesManStop(DataSetMixin):
 class KMLMapForStops(KMLMap):
     def get_kml(self, data_set):
         kml = Kml()
-        stop_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        stop_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         stops = kml.newfolder(name="Stops")
         for s in [stops.newpoint(name=s.name, coords=[(s.longitude, s.latitude)]) for s in data_set.query(TravellingSalesManStop).all()]:
             s.style = stop_style
@@ -67,7 +67,7 @@ class KMLMapForRoute(KMLMap):
         def LongLat(l):
             return (l.longitude, l.latitude)
 
-        mylocstyle = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        mylocstyle = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         LocsFolder = kml.newfolder(name="Locations")
         for p in [LocsFolder.newpoint(name=loc.name, coords=[LongLat(loc)]) for loc in data_set.query(TravellingSalesManStop).all()]:
             p.style = mylocstyle
