@@ -92,7 +92,7 @@ class MapArcInput(KMLMap):
     def get_kml(self, data_set):
         kml = Kml()
 
-        node_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        node_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         node_folder = kml.newfolder(name="Nodes")
         for p in [node_folder.newpoint(name=n.name, coords=[(n.longitude, n.latitude)]) for n in data_set.query(MaxWCutNode).all()]:
             p.style = node_style
@@ -111,12 +111,12 @@ class MapArcOutput(KMLMap):
     def get_kml(self, data_set):
         kml = Kml()
 
-        group_one_node_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        group_one_node_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         group_one_node_folder = kml.newfolder(name="Nodes - Group 1")
         for p in [group_one_node_folder.newpoint(name=n.name, coords=[(n.longitude, n.latitude)]) for n in data_set.query(MaxWCutNode).filter_by(allocated_group_index=True).all()]:
             p.style = group_one_node_style
 
-        group_two_node_style = Style(iconstyle=IconStyle(scale=0.4, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/red-circle-lv.png')))
+        group_two_node_style = Style(iconstyle=IconStyle(scale=0.4, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/red-circle-lv.png')))
         group_two_node_folder = kml.newfolder(name="Nodes - Group 2")
         for p in [group_two_node_folder.newpoint(name=n.name, coords=[(n.longitude, n.latitude)]) for n in data_set.query(MaxWCutNode).filter_by(allocated_group_index=False).all()]:
             p.style = group_two_node_style
